@@ -213,6 +213,7 @@ from pg_catalog.pg_description D
   join pg_catalog.pg_class C on D.objoid = C.oid
 where C.relnamespace = :schema_id::oid and C.relkind != 'c' and D.classoid = 'pg_catalog.pg_class'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
+-- all table-like things + seqs + iets anders?
 union all
 select T.oid id, 'T'::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
@@ -220,12 +221,14 @@ from pg_catalog.pg_description D
   left join pg_catalog.pg_class C on T.typrelid = C.oid
 where T.typnamespace = :schema_id::oid and (C.relkind = 'c' or C.relkind is null)
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
+-- relkind = c (composite types?)
 union all
 select D.objoid id, pg_catalog.translate(C.contype, 'pufc', 'kkxz')::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
   join pg_catalog.pg_constraint C on D.objoid = C.oid
 where C.connamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_constraint'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
+-- table constraints
 union all
 select D.objoid id, 't'::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
@@ -233,6 +236,7 @@ from pg_catalog.pg_description D
   join pg_catalog.pg_class C on C.oid = T.tgrelid
 where C.relnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_trigger'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
+-- triggers
 union all
 select D.objoid id, 'R'::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
@@ -240,38 +244,44 @@ from pg_catalog.pg_description D
   join pg_catalog.pg_class C on C.oid = R.ev_class
 where C.relnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_rewrite'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
+-- rules
 union all
 select D.objoid id, 'F'::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
   join pg_catalog.pg_proc P on P.oid = D.objoid
 where P.pronamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_proc'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
+-- more routines
 union all
 select D.objoid id, 'O'::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
   join pg_catalog.pg_operator O on O.oid = D.objoid
 where O.oprnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_operator'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
+-- operators
 union all
 select D.objoid id, 'f'::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
   join pg_catalog.pg_opfamily O on O.oid = D.objoid
 where O.opfnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_opfamily'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
+-- op families
 union all
 select D.objoid id, 'c'::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
   join pg_catalog.pg_opclass O on O.oid = D.objoid
 where O.opcnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_opclass'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
-#V91:union all
+-- op class
+  #V91:union all
 select D.objoid id, 'C'::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
   join pg_catalog.pg_collation C on C.oid = D.objoid
 where C.collnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_collation'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
 #.
-#V95:union all
+-- collations
+  #V95:union all
 select D.objoid id, 'P'::char as kind, D.objsubid sub_id, D.description
 from pg_catalog.pg_description D
        join pg_catalog.pg_policy P on P.oid = D.objoid
@@ -279,7 +289,107 @@ from pg_catalog.pg_description D
 where C.relnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_policy'::regclass
 #INC> and pg_catalog.age(D.xmin) <= #TXAGE
 #.
+-- security policies (also by table name...)
 
+---- RetrieveSchemaCommentsFragPgClassRels ----
+select D.objoid id, C.relkind::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_class C on D.objoid = C.oid
+where C.relnamespace = :schema_id::oid and (C.relkind != 'c' and C.relkind != 'i' and C.relkind != 'I') and D.classoid = 'pg_catalog.pg_class'::regclass
+and C.relname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragConstraints ----
+select D.objoid id, pg_catalog.translate(C.contype, 'pufc', 'kkxz')::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_constraint C on D.objoid = C.oid
+       left join pg_catalog.pg_class CLS on CLS.oid = C.conrelid
+       left join pg_catalog.pg_type TYP on TYP.oid = C.contypid
+where C.connamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_constraint'::regclass
+and CLS.relname in ( :[*f_names] ) or TYP.typname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragObjTypes ----
+select T.oid id, 'T'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_type T on T.oid = D.objoid or T.typrelid = D.objoid
+       left join pg_catalog.pg_class C on T.typrelid = C.oid
+where T.typnamespace = :schema_id::oid and (C.relkind = 'c' or C.relkind is null)
+and T.typname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragTableTriggers ----
+select D.objoid id, 't'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_trigger T on T.oid = D.objoid
+       join pg_catalog.pg_class C on C.oid = T.tgrelid
+where C.relnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_trigger'::regclass
+and C.relname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragTableRules ----
+select D.objoid id, 'R'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_rewrite R on R.oid = D.objoid
+       join pg_catalog.pg_class C on C.oid = R.ev_class
+where C.relnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_rewrite'::regclass
+and C.relname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragTableIndices ----
+select D.objoid id, ind_store.relkind::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_class ind_store
+       join pg_catalog.pg_index ind_head on ind_store.oid = ind_head.indexrelid
+       join pg_catalog.pg_class tab on tab.relnamespace = ind_store.relnamespace
+       join pg_catalog.pg_description D on ind_store.oid = D.objoid
+where ind_store.relkind in ('i', 'I')
+  and tab.relkind in ('r', 'm', 'v', 'p')
+  and D.classoid = 'pg_catalog.pg_class'::regclass
+  and tab.relnamespace = :schema_id::oid
+  and tab.relname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragProcs ----
+select D.objoid id, 'F'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_proc P on P.oid = D.objoid
+where P.pronamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_proc'::regclass
+and P.proname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragOperators ----
+select D.objoid id, 'O'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_operator O on O.oid = D.objoid
+where O.oprnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_operator'::regclass
+and O.oprname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragOpClasses ----
+select D.objoid id, 'c'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_opclass O on O.oid = D.objoid
+where O.opcnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_opclass'::regclass
+and O.opcname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragOpFamilies ----
+select D.objoid id, 'f'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_opfamily O on O.oid = D.objoid
+where O.opfnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_opfamily'::regclass
+and O.opfname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragCollations ----
+select D.objoid id, 'C'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_collation C on C.oid = D.objoid
+where C.collnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_collation'::regclass
+and C.collname in ( :[*f_names] )
+
+---- RetrieveSchemaCommentsFragSecPolicies ----
+#V95:
+select D.objoid id, 'P'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D
+       join pg_catalog.pg_policy P on P.oid = D.objoid
+       join pg_catalog.pg_class C on P.polrelid = C.oid
+where C.relnamespace = :schema_id::oid and D.classoid = 'pg_catalog.pg_policy'::regclass
+and C.relname in ( :[*f_names] )
+#:
+select D.objoid id, 'P'::char as kind, D.objsubid sub_id, D.description
+from pg_catalog.pg_description D where false
+#.
 
 ---- RetrieveDatabaseComments ----
 select D.objoid id, case
@@ -419,7 +529,8 @@ select cls.xmin as sequence_state_number,
 from pg_catalog.pg_sequence sq
     join pg_class cls on sq.seqrelid = cls.oid
     where cls.relnamespace = :schema_id::oid
-        #INC> and pg_catalog.age(cls.xmin) <= #TXAGE
+#INC>  and pg_catalog.age(cls.xmin) <= #TXAGE
+#FRAG> and cls.relname in ( :[*f_names] )
 ;
 
 
@@ -437,7 +548,8 @@ with T as (
                        from pg_catalog.pg_class
                          where relnamespace = :schema_id::oid
                          and relkind = 'S'
-                         #INC> and pg_catalog.age(xmin) <= #TXAGE
+                         #INC>  and pg_catalog.age(xmin) <= #TXAGE
+                         #FRAG> and relname in ( :[*f_names] )
                 )
 select sequence_id,
        sequence_name,
@@ -479,6 +591,7 @@ from pg_catalog.pg_type T
          left outer join pg_catalog.pg_class C
              on T.typrelid = C.oid
 where T.typnamespace = :schema_id::oid
+  #FRAG> and T.typname in ( :[*f_names] )
   #INC> and pg_catalog.age(T.xmin) <= #TXAGE
   and (T.typtype in ('d','e') or
        C.relkind = 'c'::"char" or
@@ -537,8 +650,9 @@ select T.relkind as table_kind,
        pg_catalog.pg_get_userbyid(T.relowner) as "owner"
 from pg_catalog.pg_class T
 where relnamespace = :schema_id::oid
-  and relkind in ('r', 'm', 'v', 'f', 'p')
-  #INC> and pg_catalog.age(T.xmin) <= #TXAGE
+       and relkind in ('r', 'm', 'v', 'f', 'p')
+#INC>  and pg_catalog.age(T.xmin) <= #TXAGE
+#FRAG> and T.relname in ( :[*f_names] )
 order by table_kind, table_id
 ;
 
@@ -553,6 +667,7 @@ from pg_catalog.pg_foreign_table ft
      join pg_catalog.pg_class cls on ft.ftrelid = cls.oid
 where cls.relnamespace = :schema_id::oid
   #INC> and pg_catalog.age(ft.xmin) <= #TXAGE
+  #FRAG> and cls.relname in ( :[*f_names] )
 order by table_id
 ;
 
@@ -574,6 +689,7 @@ from pg_catalog.pg_type T
 where T.typnamespace = :schema_id::oid
   and T.typtype = 'c'::"char"
   and C.relkind = 'c'::"char"
+#FRAG> and T.typname in ( :[*f_names] )
 #INC> ) sub where age <= #TXAGE
 order by #INC:type_id#:T.oid#.::bigint, #INC:att_position#:A.attnum#.
 ;
@@ -585,6 +701,7 @@ with types as (select distinct T.oid as type_id
                  on T.oid = E.enumtypid
                where T.typnamespace = :schema_id::oid
                  and T.typtype = 'e'::"char"
+               #FRAG> and T.typname in ( :[*f_names] )
                #INC> and pg_catalog.age(E.xmin) <= #TXAGE
                )
 select T.type_id as enum_id,
@@ -605,6 +722,7 @@ with T as ( select #INC>distinct
               and T.relkind in ('r', 'm', 'v', 'f', 'p')
               #INC> and (pg_catalog.age(A.xmin) <= #TXAGE or pg_catalog.age(T.xmin) <= #TXAGE)
               #INC> and A.attrelid = T.oid
+             #FRAG> and T.relname in ( :[*f_names] )
             )
 select T.table_id,
        C.attnum as column_position,
@@ -646,6 +764,7 @@ select tab.oid               table_id,
        ind_stor.xmin         state_number,
        ind_head.indisunique  is_unique,
        ind_head.indisprimary is_primary,
+       #V150: ind_head.indnullsnotdistinct #: false #. nulls_not_distinct,
        pg_catalog.pg_get_expr(ind_head.indpred, ind_head.indrelid) as condition,
        (select pg_catalog.array_agg(inhparent::bigint order by inhseqno)::varchar from pg_catalog.pg_inherits where ind_stor.oid = inhrelid) as ancestors,
        ind_stor.reltablespace tablespace_id,
@@ -659,10 +778,20 @@ from pg_catalog.pg_class tab
 where tab.relnamespace = :schema_id::oid
         and tab.relkind in ('r', 'm', 'v', 'p')
         and ind_stor.relkind in ('i', 'I')
+#FRAG>  and tab.relname in ( :[*f_names] )
 #INC>   and pg_catalog.age(ind_stor.xmin) <= #TXAGE
 
 
 ---- RetrieveIndexColumns ----
+#FRAG:
+with T as (
+  select T.oid as oid
+  from pg_catalog.pg_class T
+  where T.relnamespace = :schema_id::oid
+    and T.relkind in ('r', 'm', 'v', 'p', 'f')
+    and T.relname in ( :[*f_names] )
+)
+#.
 select ind_head.indexrelid index_id,
        k col_idx,
        #V120: k <= indnkeyatts #: true #. in_key,
@@ -691,6 +820,7 @@ from #V94: pg_catalog.pg_index #: (select *, pg_catalog.generate_subscripts(indk
          left join pg_catalog.pg_opclass
                    on pg_opclass.oid = ind_head.indclass[k-1]
          left join pg_catalog.pg_namespace opcn on opcnamespace = opcn.oid
+  #FRAG> join T on ind_head.indrelid = T.oid
 where ind_stor.relnamespace = :schema_id::oid
   and ind_stor.relkind in ('i', 'I')
 #INC>  and pg_catalog.age(ind_stor.xmin) <= #TXAGE
@@ -780,7 +910,7 @@ with schema_procs as (select prorettype, proargtypes, proallargtypes
                            )
 select type_id, pg_catalog.format_type(type_id, null) as type_spec
 from schema_arg_types
-where type_id <> 0
+where type_id <> 0 -- todo unclear how to frag
 ;
 
 
@@ -821,6 +951,7 @@ with languages as (select oid as lang_oid, lanname as lang
                          proparallel as concurrency_kind #.
                   from pg_catalog.pg_proc
                   where pronamespace = :schema_id::oid
+                    #FRAG> and proname in ( :[*f_names] )
                     and not #V110: (prokind = 'a') #: proisagg #.
                     #INC: and pg_catalog.age(xmin) <= #TXAGE #.)
 select *
@@ -882,6 +1013,7 @@ from pg_catalog.pg_aggregate A
 join pg_catalog.pg_proc P
   on A.aggfnoid = P.oid
 where P.pronamespace = :schema_id::oid
+#FRAG> and P.proname in ( :[*f_names] )
 #INC> and (pg_catalog.age(A.xmin) <= #TXAGE or pg_catalog.age(P.xmin) <= #TXAGE)
 order by P.oid
 ;
@@ -954,6 +1086,7 @@ select O.oid as op_id,
        pg_catalog.pg_get_userbyid(O.oprowner) as "owner"
 from pg_catalog.pg_operator O
 where oprnamespace = :schema_id::oid
+  #FRAG> and oprname in ( :[*f_names] )
   #INC> and pg_catalog.age(xmin) <= #TXAGE
 ;
 
@@ -977,6 +1110,7 @@ select O.oid as id,
        pg_catalog.pg_get_userbyid(O.opcowner) as "owner"
 from pg_catalog.pg_opclass O join pg_catalog.pg_opfamily F on F.oid = opcfamily
 where opcnamespace = :schema_id::oid
+  #FRAG> and opcname in ( :[*f_names] )
   #INC> and pg_catalog.age(O.xmin) <= #TXAGE
 ;
 
@@ -1050,6 +1184,7 @@ select O.oid as id,
        pg_catalog.pg_get_userbyid(O.opfowner) as "owner"
 from pg_catalog.pg_opfamily O
 where opfnamespace = :schema_id::oid
+  #FRAG> and opfname in ( :[*f_names] )
   #INC> and pg_catalog.age(xmin) <= #TXAGE
 ;
 
@@ -1073,9 +1208,12 @@ select R.ev_class as table_id,
        R.ev_enabled as rule_fire_mode,
        R.is_instead as rule_is_instead
 from pg_catalog.pg_rewrite R
-where R.ev_class in (select oid
-                     from pg_catalog.pg_class
-                     where relnamespace = :schema_id::oid)
+where R.ev_class in (
+  select oid
+  from pg_catalog.pg_class
+  where relnamespace = :schema_id::oid
+#FRAG> and relname in ( :[*f_names] )
+)
   #INC> and pg_catalog.age(R.xmin) <= #TXAGE
   and R.rulename != '_RETURN'::name
 order by R.ev_class::bigint, ev_type
@@ -1108,10 +1246,10 @@ select T.tgrelid as table_id,
        #V100: T.tgnewtable #: null #. as new_table_name,
        pg_catalog.pg_get_triggerdef(T.oid, true) as source_code
 from pg_catalog.pg_trigger T
-where T.tgrelid in (select oid
-                    from pg_catalog.pg_class
-                    where relnamespace = :schema_id::oid)
-  #INC> and pg_catalog.age(T.xmin) <= #TXAGE
+join pg_catalog.pg_class TAB on TAB.oid = T.tgrelid and TAB.relnamespace = :schema_id::oid
+where true
+  #FRAG> and TAB.relname in ( :[*f_names] )
+  #INC>  and pg_catalog.age(T.xmin) <= #TXAGE
   and not T.tgisinternal
 ;
 
@@ -1125,16 +1263,20 @@ from pg_catalog.pg_class T
   join pg_catalog.pg_namespace N on T.relnamespace = N.oid
 where N.oid = :schema_id::oid
   and T.relkind in ('m','v')
+  #FRAG> and T.relname in ( :[*f_names] )
   #INCSRC> and (pg_catalog.age(T.xmin) <= #SRCTXAGE or exists(
   #INCSRC>    select A.attrelid from pg_catalog.pg_attribute A where A.attrelid = T.oid and pg_catalog.age(A.xmin) <= #SRCTXAGE))
 ;
 
 
 ---- RetrieveRuleSources ----
-with A as ( select oid as table_id, pg_catalog.upper(relkind) as table_kind
-            from pg_catalog.pg_class
-            where relnamespace = :schema_id::oid
-              and relkind in ('r', 'm', 'v', 'f', 'p') )
+with A as (
+  select oid as table_id, pg_catalog.upper(relkind) as table_kind
+  from pg_catalog.pg_class
+  where relnamespace = :schema_id::oid
+    and relkind in ('r', 'm', 'v', 'f', 'p')
+#FRAG> and relname in ( :[*f_names] )
+)
 select table_kind,
        table_id,
        R.oid as rule_id,
@@ -1157,6 +1299,7 @@ select oid as id,
        prosrc as source_text
 from pg_catalog.pg_proc
 where pronamespace = :schema_id::oid
+  #FRAG> and pg_proc.proname in ( :[*f_names] )
   #INC> and pg_catalog.age(xmin) <= #SRCTXAGE
   and not #V110: (prokind = 'a') #: proisagg #.
   and prolang not in (select lang from system_languages)
@@ -1227,6 +1370,7 @@ select oid as id,
        pg_catalog.pg_get_userbyid(collowner) as "owner"
 from pg_catalog.pg_collation
 where collnamespace = :schema_id::oid
+  #FRAG> and collname in ( :[*f_names] )
   #INC> and pg_catalog.age(xmin) <= #TXAGE
 ;
 
@@ -1356,6 +1500,7 @@ select
 from pg_catalog.pg_policy P
        join pg_catalog.pg_class C on polrelid = C.oid
 where relnamespace = :schema_id::oid
+  #FRAG> and C.relname in ( :[*f_names] )
   #INC> and pg_catalog.age(P.xmin) <= #TXAGE
 order by polrelid
 ;
\ No newline at end of file
